@@ -26,8 +26,10 @@ modules = [
     "ao3",
     "arcalive",
     "architizer",
+    "arena",
     "artstation",
     "aryion",
+    "audiochan",
     "batoto",
     "bbc",
     "behance",
@@ -39,6 +41,7 @@ modules = [
     "booth",
     "bunkr",
     "catbox",
+    "cfake",
     "chevereto",
     "cien",
     "civitai",
@@ -54,6 +57,7 @@ modules = [
     "discord",
     "dynastyscans",
     "e621",
+    "eporner",
     "erome",
     "everia",
     "exhentai",
@@ -63,6 +67,8 @@ modules = [
     "fantia",
     "fapello",
     "fapachi",
+    "fikfap",
+    "fitnakedgirls",
     "flickr",
     "furaffinity",
     "furry34",
@@ -140,6 +146,7 @@ modules = [
     "nozomi",
     "nsfwalbum",
     "nudostar",
+    "okporn",
     "paheal",
     "patreon",
     "pexels",
@@ -158,12 +165,12 @@ modules = [
     "poringa",
     "pornhub",
     "pornpics",
+    "pornstarstube",
     "postmill",
     "rawkuma",
     "reactor",
     "readcomiconline",
     "realbooru",
-    "redbust",
     "reddit",
     "redgifs",
     "rule34us",
@@ -179,7 +186,6 @@ modules = [
     "senmanga",
     "sexcom",
     "shimmie2",
-    "simpcity",
     "simplyhentai",
     "sizebooru",
     "skeb",
@@ -190,6 +196,7 @@ modules = [
     "speakerdeck",
     "steamgriddb",
     "subscribestar",
+    "sxypix",
     "szurubooru",
     "tapas",
     "tcbscans",
@@ -226,6 +233,7 @@ modules = [
     "wikifeet",
     "wikimedia",
     "xasiat",
+    "xenforo",
     "xfolio",
     "xhamster",
     "xvideos",
@@ -299,7 +307,7 @@ def _list_classes():
 def _modules_internal():
     globals_ = globals()
     for module_name in modules:
-        yield __import__(module_name, globals_, None, (), 1)
+        yield __import__(module_name, globals_, None, None, 1)
 
 
 def _modules_path(path, files):
