@@ -149,6 +149,19 @@ __tests__ = (
         "tags": [],
         "collectionId": None,
     },
+    "tags[*]": {
+        "automated"  : bool,
+        "concrete"   : bool,
+        "downVotes"  : int,
+        "id"         : int,
+        "lastUpvote" : None,
+        "name"       : str,
+        "needsReview": bool,
+        "nsfwLevel"  : 1,
+        "score"      : int,
+        "type"       : {"Label", "UserGenerated"},
+        "upVotes"    : int,
+    },
     "model": {
         "id": 703211,
         "name": "メイド　クラシック/maid classic",
