@@ -60,6 +60,13 @@ __tests__ = (
     "#count"   : 200,
 },
 
+{
+    "#url"     : "https://rule34.paheal.net/post/list/non_existant_tag/1",
+    "#category": ("shimmie2", "paheal", "tag"),
+    "#class"   : paheal.PahealTagExtractor,
+    "#count"   : 0,
+},
+
 {
     "#url"     : "https://rule34.paheal.net/post/view/481609",
     "#category": ("shimmie2", "paheal", "post"),
@@ -116,4 +123,11 @@ __tests__ = (
     "width"    : 1768,
 },
 
+{
+    "#url"     : "https://rule34.paheal.net/post/view/7",
+    "#category": ("shimmie2", "paheal", "post"),
+    "#class"   : paheal.PahealPostExtractor,
+    "#count"   : 0,
+},
+
 )
