@@ -374,6 +374,40 @@ class ExecTest(BasePostprocessorTest):
         m_aa.assert_called_once_with(self.pathfmt.kwdict)
         m_ac.assert_called_once()
 
+    def test_verbose_string(self):
+        self._create({
+            "command": "echo foo bar",
+            "verbose": False,
+        })
+
+        with patch("gallery_dl.util.Popen") as p, \
+                self.assertLogs(level=10) as log_info:
+            i = Mock()
+            i.wait.return_value = 123
+            p.return_value = i
+            self._trigger(("after",))
+
+        msg = "DEBUG:postprocessor.exec:Running 'echo'"
+        self.assertEqual(log_info.output[0], msg)
+        self.assertIn("'echo' returned with non-zero ", log_info.output[1])
+
+    def test_verbose_list(self):
+        self._create({
+            "command": ["echo", "foo", "bar"],
+            "verbose": False,
+        })
+
+        with patch("gallery_dl.util.Popen") as p, \
+                self.assertLogs(level=10) as log_info:
+            i = Mock()
+            i.wait.return_value = 123
+            p.return_value = i
+            self._trigger(("after",))
+
+        msg = "DEBUG:postprocessor.exec:Running 'echo'"
+        self.assertEqual(log_info.output[0], msg)
+        self.assertIn("'echo' returned with non-zero ", log_info.output[1])
+
 
 class HashTest(BasePostprocessorTest):
 
@@ -453,7 +487,7 @@ class MetadataTest(BasePostprocessorTest):
             self._trigger()
 
         path = f"{self.pathfmt.realpath}.JSON"
-        m.assert_called_once_with(path, "w", encoding="utf-8")
+        m.assert_called_once_with(path, "w", encoding="utf-8", newline=None)
 
         self.assertEqual(self._output(m), """{
     "category": "test",
@@ -473,6 +507,7 @@ class MetadataTest(BasePostprocessorTest):
             "indent"    : None,
             "open"      : "a",
             "encoding"  : "UTF-8",
+            "newline"   : "\r\n",
             "extension" : "JSON",
         }, {
             "public"    : "hello ワールド",
@@ -487,7 +522,9 @@ class MetadataTest(BasePostprocessorTest):
             self._trigger()
 
         path = f"{self.pathfmt.realpath}.JSON"
-        m.assert_called_once_with(path, "a", encoding="UTF-8")
+        m.assert_called_once_with(path, "a", encoding="UTF-8", newline='\r\n')
+        # Since we mocked the call to open,
+        # we don't actually see the effect of setting newline.
         self.assertEqual(self._output(m), """{\
 "_private" : "foo \\u30d0\\u30fc",\
 "category" : "test",\
@@ -508,7 +545,7 @@ class MetadataTest(BasePostprocessorTest):
             self._trigger()
 
         path = f"{self.pathfmt.realpath}.txt"
-        m.assert_called_once_with(path, "w", encoding="utf-8")
+        m.assert_called_once_with(path, "w", encoding="utf-8", newline=None)
         self.assertEqual(self._output(m), "foo\nbar\nbaz\n")
 
     def test_metadata_tags_split_1(self):
@@ -599,7 +636,7 @@ class MetadataTest(BasePostprocessorTest):
             self._trigger()
 
         path = f"{self.pathfmt.realdirectory}file.json"
-        m.assert_called_once_with(path, "w", encoding="utf-8")
+        m.assert_called_once_with(path, "w", encoding="utf-8", newline=None)
 
     def test_metadata_extfmt_2(self):
         self._create({
@@ -611,7 +648,7 @@ class MetadataTest(BasePostprocessorTest):
             self._trigger()
 
         path = f"{self.pathfmt.realdirectory}file.2.EXT-data:tESt"
-        m.assert_called_once_with(path, "w", encoding="utf-8")
+        m.assert_called_once_with(path, "w", encoding="utf-8", newline=None)
 
     def test_metadata_directory(self):
         self._create({
@@ -622,7 +659,7 @@ class MetadataTest(BasePostprocessorTest):
             self._trigger()
 
         path = f"{self.pathfmt.realdirectory}metadata/file.ext.json"
-        m.assert_called_once_with(path, "w", encoding="utf-8")
+        m.assert_called_once_with(path, "w", encoding="utf-8", newline=None)
 
     def test_metadata_directory_2(self):
         self._create({
@@ -634,7 +671,7 @@ class MetadataTest(BasePostprocessorTest):
             self._trigger()
 
         path = f"{self.pathfmt.realdirectory}metadata/file.json"
-        m.assert_called_once_with(path, "w", encoding="utf-8")
+        m.assert_called_once_with(path, "w", encoding="utf-8", newline=None)
 
     def test_metadata_directory_format(self):
         self._create(
@@ -646,7 +683,7 @@ class MetadataTest(BasePostprocessorTest):
             self._trigger()
 
         path = f"{self.pathfmt.realdirectory}../json/12500/file.ext.json"
-        m.assert_called_once_with(path, "w", encoding="utf-8")
+        m.assert_called_once_with(path, "w", encoding="utf-8", newline=None)
 
     def test_metadata_directory_empty(self):
         self._create(
@@ -657,7 +694,7 @@ class MetadataTest(BasePostprocessorTest):
             self._trigger()
 
         path = f"{self.pathfmt.realdirectory}./file.ext.json"
-        m.assert_called_once_with(path, "w", encoding="utf-8")
+        m.assert_called_once_with(path, "w", encoding="utf-8", newline=None)
 
     def test_metadata_basedirectory(self):
         self._create({"base-directory": True})
@@ -666,7 +703,7 @@ class MetadataTest(BasePostprocessorTest):
             self._trigger()
 
         path = f"{self.pathfmt.basedirectory}file.ext.json"
-        m.assert_called_once_with(path, "w", encoding="utf-8")
+        m.assert_called_once_with(path, "w", encoding="utf-8", newline=None)
 
     def test_metadata_basedirectory_custom(self):
         self._create({
@@ -678,7 +715,7 @@ class MetadataTest(BasePostprocessorTest):
             self._trigger()
 
         path = "/home/test/meta/file.ext.json"
-        m.assert_called_once_with(path, "w", encoding="utf-8")
+        m.assert_called_once_with(path, "w", encoding="utf-8", newline=None)
 
     def test_metadata_filename(self):
         self._create({
@@ -690,7 +727,7 @@ class MetadataTest(BasePostprocessorTest):
             self._trigger()
 
         path = f"{self.pathfmt.realdirectory}test_file__meta_.data"
-        m.assert_called_once_with(path, "w", encoding="utf-8")
+        m.assert_called_once_with(path, "w", encoding="utf-8", newline=None)
 
     def test_metadata_meta_path(self):
         self._create({
@@ -790,7 +827,7 @@ class MetadataTest(BasePostprocessorTest):
         self.assertGreater(len(self._output(m)), 0)
 
         path = f"{self.pathfmt.realdirectory}file.ext.json"
-        m.assert_called_once_with(path, "w", encoding="utf-8")
+        m.assert_called_once_with(path, "w", encoding="utf-8", newline=None)
 
     def test_metadata_option_skip_false(self):
         self._create({"skip": False})
@@ -802,6 +839,28 @@ class MetadataTest(BasePostprocessorTest):
         self.assertTrue(not e.called)
         self.assertTrue(m.called)
 
+    def test_metadata_option_newline(self):
+        self._create({
+            "newline": "\r\n",
+            "filename"      : "data.json",
+            "directory"     : "",
+            "base-directory": self.dir.name,
+        })
+
+        self._trigger()
+
+        path = os.path.join(self.dir.name, "data.json")
+        with open(path, newline="") as fp:
+            content = fp.read()
+
+        self.assertEqual(content, """\
+{\r\n\
+    "category": "test",\r\n\
+    "filename": "file",\r\n\
+    "extension": "ext"\r\n\
+}\r\n\
+""")
+
     def test_metadata_option_include(self):
         self._create(
             {"include": ["_private", "filename", "foo"], "sort": True},
